==> neo4j-kernel-4.3.2-sources.jar: org/neo4j/kernel/impl/util/watcher/FileSystemWatcherService.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.util.watcher;

import org.neo4j.io.fs.watcher.FileWatcher;
import org.neo4j.kernel.lifecycle.Lifecycle;
import org.neo4j.kernel.lifecycle.LifecycleAdapter;

/**
 * Interface to be able to recognise file system watcher service in the set of discoverable services,
 * need to extend {@link Lifecycle} since service should be restartable in clustering setup
 * (for example during store branching)
 */
public interface FileSystemWatcherService extends Lifecycle
{
    FileSystemWatcherService EMPTY_WATCHER = new EmptyWatcherService();

    FileWatcher getFileWatcher();

    class EmptyWatcherService extends LifecycleAdapter implements FileSystemWatcherService
    {
        @Override
        public FileWatcher getFileWatcher()
        {
            return FileWatcher.SILENT_WATCHER;
        }
    }
}

==> neo4j-kernel-5.3.0-sources.jar: org/neo4j/kernel/impl/util/watcher/FileSystemWatcherService.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.util.watcher;

import org.neo4j.io.fs.watcher.FileWatcher;
import org.neo4j.kernel.lifecycle.Lifecycle;
import org.neo4j.kernel.lifecycle.LifecycleAdapter;

/**
 * Interface to be able to recognise file system watcher service in the set of discoverable services,
 * need to extend {@link Lifecycle} since service should be restartable in clustering setup
 * (for example during store branching)
 */
public interface FileSystemWatcherService extends Lifecycle {
    FileSystemWatcherService EMPTY_WATCHER = new EmptyWatcherService();

    FileWatcher getFileWatcher();

    class EmptyWatcherService extends LifecycleAdapter implements FileSystemWatcherService {
        @Override
        public FileWatcher getFileWatcher() {
            return FileWatcher.SILENT_WATCHER;
        }
    }
}
